@@ -4,17 +4,13 @@
 # Simple seesaw test reading analog value
 # on SAMD09, analog in can be pins 2, 3, or 4
 # on Attiny8x7, analog in can be pins 0, 1, 2, 3, 6, 7, 18, 19, 20
-#
-# See the seesaw Learn Guide for wiring details:
-# https://learn.adafruit.com/adafruit-seesaw-atsamd09-breakout?view=all#circuitpython-wiring-and-test
 
 import time
 import board
 from adafruit_seesaw.seesaw import Seesaw
 from adafruit_seesaw.analoginput import AnalogInput
 
-i2c_bus = board.I2C()
-ss = Seesaw(i2c_bus)
+ss = Seesaw(board.I2C())
 
 analogin_pin = 2
 analog_in = AnalogInput(ss, analogin_pin)
